@@ -4,7 +4,7 @@ from datetime import datetime
 LOG_FORMAT = "[%(asctime)s][%(levelname)s] %(message)s"
 logging.basicConfig(
     filename="moonlight_{}.log".format(datetime.now().strftime("%Y%m%d")),
-    level=logging.INFO,
+    level=logging.DEBUG,
     format=LOG_FORMAT,
 )
 
